==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/nl.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Defaka',
        'Aghb' => 'Kaukasisch Albanees',
        'Ahom' => 'Ahom',
        'Arab' => 'Arabisch',
        'Aran' => 'Nastaliq',
        'Armi' => 'Keizerlijk Aramees',
        'Armn' => 'Armeens',
        'Avst' => 'Avestaans',
        'Bali' => 'Balinees',
        'Bamu' => 'Bamoun',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Bengaals',
        'Bhks' => 'Bhaiksuki',
        'Blis' => 'Blissymbolen',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'braille',
        'Bugi' => 'Buginees',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'Verenigde Canadese Aboriginal-symbolen',
        'Cari' => 'Carisch',
        'Cham' => 'Cham',
        'Cher' => 'Cherokee',
        'Chrs' => 'Chorasmisch',
        'Cirt' => 'Cirth',
        'Copt' => 'Koptisch',
        'Cpmn' => 'Cypro-Minoïsch',
        'Cprt' => 'Cyprisch',
        'Cyrl' => 'Cyrillisch',
        'Cyrs' => 'Oudkerkslavisch Cyrillisch',
        'Deva' => 'Devanagari',
        'Diak' => 'Dives Akuru',
        'Dogr' => 'Dogra',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployan snelschrift',
        'Egyd' => 'Egyptisch demotisch',
        'Egyh' => 'Egyptisch hiëratisch',
        'Egyp' => 'Egyptische hiërogliefen',
        'Elba' => 'Elbasan',
        'Elym' => 'Elymaisch',
        'Ethi' => 'Ethiopisch',
        'Geok' => 'Georgisch Khutsuri',
        'Geor' => 'Georgisch',
        'Glag' => 'Glagolitisch',
        'Gong' => 'Gunjala Gondi',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gothisch',
        'Gran' => 'Grantha',
        'Grek' => 'Grieks',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han met Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'vereenvoudigd',
        'Hant' => 'traditioneel',
        'Hatr' => 'Hatran',
        'Hebr' => 'Hebreeuws',
        'Hira' => 'Hiragana',
        'Hluw' => 'Anatolische hiërogliefen',
        'Hmng' => 'Pahawh Hmong',
        'Hmnp' => 'Nyiakeng Puachue Hmong',
        'Hrkt' => 'Katakana of Hiragana',
        'Hung' => 'Oudhongaars',
        'Inds' => 'Indus',
        'Ital' => 'Oud-italisch',
        'Jamo' => 'Jamo',
        'Java' => 'Javaans',
        'Jpan' => 'Japans',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Khoj' => 'Khojki',
        'Kits' => 'Kitaans kleinschrift',
        'Knda' => 'Kannada',
        'Kore' => 'Koreaans',
        'Kpel' => 'Kpelle',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Laotiaans',
        'Latf' => 'Gotisch Latijns',
        'Latg' => 'Gaelisch Latijns',
        'Latn' => 'Latijns',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Lineair A',
        'Linb' => 'Lineair B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Lycisch',
        'Lydi' => 'Lydisch',
        'Mahj' => 'Mahajani',
        'Maka' => 'Makasar',
        'Mand' => 'Mandaeans',
        'Mani' => 'Manicheaans',
        'Marc' => 'Marchen',
        'Maya' => 'Mayahiërogliefen',
        'Medf' => 'Medefaidrin',
        'Mend' => 'Mende',
        'Merc' => 'Meroitisch cursief',
        'Mero' => 'Meroïtisch',
        'Mlym' => 'Malayalam',
        'Modi' => 'Modi',
        'Mong' => 'Mongools',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei',
        'Mult' => 'Multani',
        'Mymr' => 'Birmaans',
        'Nand' => 'Nandinagari',
        'Narb' => 'Oud Noord-Arabisch',
        'Nbat' => 'Nabateaans',
        'Newa' => 'Newari',
        'Nkgb' => 'Naxi Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orkhon',
        'Orya' => 'Odia',
        'Osge' => 'Osage',
        'Osma' => 'Osmanya',
        'Ougr' => 'Oud Oeigoers',
        'Palm' => 'Palmyreens',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Oudpermisch',
        'Phag' => 'Phags-pa',
        'Phli' => 'Inscriptioneel Pahlavi',
        'Phlp' => 'Psalmen Pahlavi',
        'Phlv' => 'Boek Pahlavi',
        'Phnx' => 'Foenicisch',
        'Plrd' => 'Pollard-fonetisch',
        'Prti' => 'Inscriptioneel Parthisch',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi Rohingya',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runic',
        'Samr' => 'Samaritaans',
        'Sara' => 'Sarati',
        'Sarb' => 'Oud Zuid-Arabisch',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'Shavian',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Sindhi',
        'Sinh' => 'Singalees',
        'Sogd' => 'Sogdisch',
        'Sogo' => 'Oud Sogdisch',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Soendanees',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Syriac',
        'Syre' => 'Estrangelo Aramees',
        'Syrj' => 'West-Aramees',
        'Syrn' => 'Oost-Aramees',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'Nieuw Tai Lue',
        'Taml' => 'Tamil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibetaans',
        'Tirh' => 'Tirhuta',
        'Tnsa' => 'Tangsa',
        'Toto' => 'Totoschrift',
        'Ugar' => 'Ugaritisch',
        'Vaii' => 'Vai',
        'Visp' => 'Zichtbare spraak',
        'Vith' => 'Vithkuqi',
        'Wara' => 'Varang Kshiti',
        'Wcho' => 'Wancho',
        'Wole' => 'Woleai',
        'Xpeo' => 'Oudperzisch',
        'Xsux' => 'Sumero-Akkadian Cuneiform',
        'Yezi' => 'Jezidi',
        'Yiii' => 'Yi',
        'Zanb' => 'vierkant Zanabazar',
        'Zinh' => 'Overgeërfd',
        'Zmth' => 'wiskundige notatie',
        'Zsye' => 'emoji',
        'Zsym' => 'symbolen',
        'Zxxx' => 'ongeschreven',
        'Zyyy' => 'algemeen',
    ],
];

==> symfony_8.0.2+dfsg.orig.tar.xz: symfony-8.0.2/src/Symfony/Component/Intl/Resources/data/scripts/nl.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Defaka',
        'Aghb' => 'Kaukasisch Albanees',
        'Arab' => 'Arabisch',
        'Aran' => 'Nastaliq',
        'Armi' => 'Keizerlijk Aramees',
        'Armn' => 'Armeens',
        'Avst' => 'Avestaans',
        'Bali' => 'Balinees',
        'Bamu' => 'Bamoun',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Bengaals',
        'Berf' => 'Beria Erfe',
        'Bhks' => 'Bhaiksuki',
        'Blis' => 'Blissymbolen',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'braille',
        'Bugi' => 'Buginees',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'Verenigde Canadese Aboriginal-symbolen',
        'Cari' => 'Carisch',
        'Cher' => 'Cherokee',
        'Chrs' => 'Chorasmisch',
        'Cirt' => 'Cirth',
        'Copt' => 'Koptisch',
        'Cpmn' => 'Cypro-Minoïsch',
        'Cprt' => 'Cyprisch',
        'Cyrl' => 'Cyrillisch',
        'Cyrs' => 'Oudkerkslavisch Cyrillisch',
        'Deva' => 'Devanagari',
        'Diak' => 'Dives Akuru',
        'Dogr' => 'Dogra',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployan snelschrift',
        'Egyd' => 'Egyptisch demotisch',
        'Egyh' => 'Egyptisch hiëratisch',
        'Egyp' => 'Egyptische hiërogliefen',
        'Elba' => 'Elbasan',
        'Elym' => 'Elymaisch',
        'Ethi' => 'Ethiopisch',
        'Gara' => 'Garay',
        'Geok' => 'Georgisch Khutsuri',
        'Geor' => 'Georgisch',
        'Glag' => 'Glagolitisch',
        'Gong' => 'Gunjala Gondi',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gothisch',
        'Gran' => 'Grantha',
        'Grek' => 'Grieks',
        'Gujr' => 'Gujarati',
        'Gukh' => 'Gurung Khema',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han met Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'vereenvoudigd',
        'Hant' => 'traditioneel',
        'Hatr' => 'Hatran',
        'Hebr' => 'Hebreeuws',
        'Hira' => 'Hiragana',
        'Hluw' => 'Anatolische hiërogliefen',
        'Hmng' => 'Pahawh Hmong',
        'Hmnp' => 'Nyiakeng Puachue Hmong',
        'Hrkt' => 'Katakana of Hiragana',
        'Hung' => 'Oudhongaars',
        'Inds' => 'Indus',
        'Ital' => 'Oud-italisch',
        'Java' => 'Javaans',
        'Jpan' => 'Japans',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Kawi' => 'Kawi-taal',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Khoj' => 'Khojki',
        'Kits' => 'Kitaans kleinschrift',
        'Knda' => 'Kannada',
        'Kore' => 'Koreaans',
        'Kpel' => 'Kpelle',
        'Krai' => 'Kirat Rai',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Laotiaans',
        'Latf' => 'Gotisch Latijns',
        'Latg' => 'Gaelisch Latijns',
        'Latn' => 'Latijns',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Lineair A',
        'Linb' => 'Lineair B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Lycisch',
        'Lydi' => 'Lydisch',
        'Mahj' => 'Mahajani',
        'Maka' => 'Makasar',
        'Mand' => 'Mandaeans',
        'Mani' => 'Manicheaans',
        'Marc' => 'Marchen',
        'Maya' => 'Mayahiërogliefen',
        'Medf' => 'Medefaidrin',
        'Mend' => 'Mende',
        'Merc' => 'Meroitisch cursief',
        'Mero' => 'Meroïtisch',
        'Mlym' => 'Malayalam',
        'Mong' => 'Mongools',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei',
        'Mult' => 'Multani',
        'Mymr' => 'Birmaans',
        'Nagm' => 'Nag Mundari',
        'Nand' => 'Nandinagari',
        'Narb' => 'Oud Noord-Arabisch',
        'Nbat' => 'Nabateaans',
        'Newa' => 'Newari',
        'Nkgb' => 'Naxi Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Onao' => 'Ol Onal',
        'Orkh' => 'Orkhon',
        'Orya' => 'Odia',
        'Osge' => 'Osage',
        'Osma' => 'Osmanya',
        'Ougr' => 'Oud Oeigoers',
        'Palm' => 'Palmyreens',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Oudpermisch',
        'Phag' => 'Phags-pa',
        'Phli' => 'Inscriptioneel Pahlavi',
        'Phlp' => 'Psalmen Pahlavi',
        'Phlv' => 'Boek Pahlavi',
        'Phnx' => 'Foenicisch',
        'Plrd' => 'Pollard-fonetisch',
        'Prti' => 'Inscriptioneel Parthisch',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi Rohingya',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runic',
        'Samr' => 'Samaritaans',
        'Sara' => 'Sarati',
        'Sarb' => 'Oud Zuid-Arabisch',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'Shavian',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sidt' => 'Sidetisch',
        'Sind' => 'Sindhi',
        'Sinh' => 'Singalees',
        'Sogd' => 'Sogdisch',
        'Sogo' => 'Oud Sogdisch',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Soendanees',
        'Sunu' => 'Sunuwar',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Syriac',
        'Syre' => 'Estrangelo Aramees',
        'Syrj' => 'West-Aramees',
        'Syrn' => 'Oost-Aramees',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'Nieuw Tai Lue',
        'Taml' => 'Tamil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Tayo' => 'Tai Yo',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Tibt' => 'Tibetaans',
        'Tirh' => 'Tirhuta',
        'Tnsa' => 'Tangsa',
        'Todr' => 'Todhri',
        'Tols' => 'Tolong Siki',
        'Toto' => 'Totoschrift',
        'Tutg' => 'Tulu-Tigalari',
        'Ugar' => 'Ugaritisch',
        'Vaii' => 'Vai',
        'Visp' => 'Zichtbare spraak',
        'Vith' => 'Vithkuqi',
        'Wara' => 'Varang Kshiti',
        'Wcho' => 'Wancho',
        'Wole' => 'Woleai',
        'Xpeo' => 'Oudperzisch',
        'Xsux' => 'Sumero-Akkadian Cuneiform',
        'Yezi' => 'Jezidi',
        'Yiii' => 'Yi',
        'Zanb' => 'vierkant Zanabazar',
        'Zinh' => 'Overgeërfd',
        'Zmth' => 'wiskundige notatie',
        'Zsye' => 'emoji',
        'Zsym' => 'symbolen',
        'Zxxx' => 'ongeschreven',
        'Zyyy' => 'algemeen',
    ],
];
